<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en" sourcelanguage="en">
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Note</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Report</name>
    <message>
        <source>Time Sheet Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Company:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Address:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Phone:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fax:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Email:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Website:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>N/A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prepend currency symbol</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hourly rate:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tax rate:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Currency symbol:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contact Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Web Page (*.html *.htm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>iCalendar (*.ics)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Outlook CSV (*.csv)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View Reports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Phone: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fax: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hours</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subtotal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Taxes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Total</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation>
            <numerusform>%n hour</numerusform>
            <numerusform>%n hours</numerusform>
        </translation>
    </message>
    <message>
        <source>%L1 hours</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SessionDelegate</name>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Session conflicts with other sessions.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SessionDialog</name>
    <message>
        <source>Add Session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Task:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Session</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SessionModel</name>
    <message>
        <source>Total</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Task</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hours</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Daily</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weekly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Monthly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Report</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>00:00:00</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>S&amp;ettings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Columns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Decimal Totals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Inline Editing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Timer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show only unbilled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show only this year</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show only this month</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show only this week</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Session conflicts with other sessions.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to read time data.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to write time data.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There are timers running. Stop timers and quit?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A program to help track spent time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Question</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Create Report...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View R&amp;eports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel this session?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter project name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to create time data location.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to move time data location.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A project with that name already exists.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove selected project?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove selected session?</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n timer(s) running</source>
        <translation>
            <numerusform>%n timer running</numerusform>
            <numerusform>%n timers running</numerusform>
        </translation>
    </message>
    <message>
        <source>Kapow Punch Clock</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Punch clock program</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Store settings as INI format in specified file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not create automatic backups of time data.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The time data file to use.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
